Learn R Programming

riskmetric (version 0.2.5)

assess_covr_coverage: Assess a package code coverage using the `covr` package

Description

Assess a package code coverage using the `covr` package

Usage

assess_covr_coverage(x, ...)

Value

a pkg_metric containing a list containing fields 'filecoverage' and 'totalcoverage' containing a named numeric vector of file unit test coverage and a singular numeric value representing overall test coverage respectively.

Arguments

x

a pkg_ref package reference object

...

additional arguments passed on to S3 methods, rarely used

See Also

metric_score.pkg_metric_covr_coverage

Examples

Run this code
if (FALSE) {
assess_covr_coverage(pkg_ref("riskmetric"))
}

Run the code above in your browser using DataLab