Learn R Programming

riskmetric (version 0.2.5)

assess_dependencies: Assessment of dependency footprint for a specific package

Description

Only Depends, Imports and LinkingTo dependencies are assessed because they are required

Usage

assess_dependencies(x, ...)

Value

a pkg_metric containing a dataframe of package names and they type of dependency the package being assess has to them

Arguments

x

a pkg_ref package reference object

...

additional arguments passed on to S3 methods, rarely used

Details

The more packages a package relies on the more chances for errors exist.

See Also

metric_score.pkg_metric_dependencies

Examples

Run this code
if (FALSE) {
assess_dependencies(pkg_ref("riskmetric"))
}

Run the code above in your browser using DataLab