assess_downloads_1yr: Assess a package for the number of downloads in the past year
Description
Assess a package for the number of downloads in the past year
Usage
assess_downloads_1yr(x, ...)
Value
a pkg_metric containing a numeric value between [0,1] indicating the volume of downloads
Arguments
x
a pkg_ref package reference object
...
additional arguments passed on to S3 methods, rarely used
Details
The more times a package has been downloaded the more extensive the user testing and the greater chance there is of someone finding a bug and logging it.