Learn R Programming

riskmetric (version 0.2.5)

assess_has_bug_reports_url: Assess a package for the presence of a url field where bugs can be reported.

Description

Assess a package for the presence of a url field where bugs can be reported.

Usage

assess_has_bug_reports_url(x, ...)

Value

a pkg_metric containing a character value containing the BugReports field contents

Arguments

x

a pkg_ref package reference object

...

additional arguments passed on to S3 methods, rarely used

See Also

metric_score.pkg_metric_has_bug_reports_url

Examples

Run this code
if (FALSE) {
assess_has_bug_reports_url(pkg_ref("riskmetric"))
}

Run the code above in your browser using DataLab