Learn R Programming

riskmetric (version 0.2.5)

assess_has_examples: Assess a package for the presence of example or usage fields in function documentation

Description

Assess a package for the presence of example or usage fields in function documentation

Usage

assess_has_examples(x, ...)

Value

a pkg_metric containing an integer value indicating the proportion of discovered files with examples

Arguments

x

a pkg_ref package reference object

...

additional arguments passed on to S3 methods, rarely used

See Also

metric_score.pkg_metric_has_examples

Examples

Run this code
if (FALSE) {
assess_has_examples(pkg_ref("riskmetric"))
}

Run the code above in your browser using DataLab