powered by
Assess a package for an associated source control url
assess_has_source_control(x, ...)
a pkg_metric containing a character vector of source control urls associated with the package
pkg_metric
a pkg_ref package reference object
pkg_ref
additional arguments passed on to S3 methods, rarely used
metric_score.pkg_metric_has_source_control
if (FALSE) { assess_has_source_control(pkg_ref("riskmetric")) }
Run the code above in your browser using DataLab