Learn R Programming

riskmetric (version 0.2.5)

is_url_subpath_of: check if a url originates from a list of repo urls

Description

check if a url originates from a list of repo urls

Usage

is_url_subpath_of(url, urls)

Value

logical vector indicating which base urls have a sub url of

url

Arguments

url

a url which may stem from one of the provided base urls

urls

vector of base urls