Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_export_help: Score a package for availability of documentation for exported values

Description

Coerce a logical vector indicating availability of export documentation

Usage

# S3 method for pkg_metric_export_help
metric_score(x, ...)

Value

1 if any NEWS files are found, otherwise 0

Arguments

x

a pkg_metric_export_help packge metric object

...

additional arguments unused

Examples

Run this code
if (FALSE) metric_score(assess_export_help(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab