The scoring function is the classic logistic curve $$
1 / (1 + exp(-k(x-x[0])) $$ with a square root scale for the number of exported objects
\(x = sqrt(length(x))\), sigmoid midpoint is 25 exported objects, ie. \(x[0] =
sqrt(5)\), and logistic growth rate of \(k = 0.25\).
$$ 1 / (1 + exp(-0.25 * sqrt(length(x))-sqrt(25))) $$