Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_has_examples: Score a package for the presence of a example or usage fields

Description

Coerce a logical vector indicating availability of example or usage documentation

Usage

# S3 method for pkg_metric_has_examples
metric_score(x, ...)

Value

1 if any example or usage fields are found, otherwise 0

Arguments

x

a pkg_metric_has_examples packge metric object

...

additional arguments unused

Examples

Run this code
if (FALSE) metric_score(assess_has_examples(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab