Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_has_maintainer: Score a package for inclusion of an associated maintainer

Description

Coerce a list of maintainers into a numeric value indicating whether the number of listed maintainers is greater than 0.

Usage

# S3 method for pkg_metric_has_maintainer
metric_score(x, ...)

Value

1 if any maintainer is provided, otherwise 0

Arguments

x

a pkg_metric_has_maintainer packge metric object

...

additional arguments unused

Examples

Run this code
if (FALSE) metric_score(assess_has_maintainer(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab