Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_has_news: Score a package for the presence of a NEWS file

Description

Coerce the number of news files to binary indication of valid NEWS files

Usage

# S3 method for pkg_metric_has_news
metric_score(x, ...)

Value

1 if any NEWS files are found, otherwise 0

Arguments

x

a pkg_metric_has_news packge metric object

...

additional arguments unused

Examples

Run this code
if (FALSE) metric_score(assess_has_news(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab