Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_has_source_control: Score a package for inclusion of an associated source control url

Description

Coerce a list of source control urls into a numeric value indicating whether the number of listed urls is greater than 0.

Usage

# S3 method for pkg_metric_has_source_control
metric_score(x, ...)

Value

1 if any source control url is provided, otherwise 0

Arguments

x

a pkg_metric_has_source_control packge metric object

...

additional arguments unused

Examples

Run this code
if (FALSE) metric_score(assess_has_source_control(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab