Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_has_vignettes: Score a package for the presence of a Vignettes file

Description

Coerce the number of vignettes files to binary indication of valid Vignettes

Usage

# S3 method for pkg_metric_has_vignettes
metric_score(x, ...)

Value

1 if any Vignettes files are found, otherwise 0

Arguments

x

a pkg_metric_has_vignettes packge metric object

...

additional arguments unused

Examples

Run this code
if (FALSE) metric_score(assess_has_vignettes(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab