The scoring function is the classic logistic curve $$
1 / (1 + exp(-k(x-x[0])) $$ with a square root scale for the number of reverse dependencies
\(x = sqrt(length(x))\), sigmoid midpoint is 5 reverse dependencies, ie. \(x[0] =
sqrt(5)\), and logistic growth rate of \(k = 0.5\).
$$ 1 / (1 + -0.5 * exp(sqrt(length(x)) - sqrt(5))) $$