pkg_metric: A helper for structuring assessment return objects for dispatch with the
score function
Description
A helper for structuring assessment return objects for dispatch with the
score function
Usage
pkg_metric(x = NA, ..., class = c())
Arguments
- x
data to store as a pkg_metric
- ...
additional attributes to bind to the pkg_metric object
- class
a subclass to differentiate the pkg_metric object