Handle pretty printing of expression output
# S3 method for with_eval_recording
print(x, playback = FALSE, cr = TRUE, ..., sleep = 0)a print message
expr_output to print
a logical indicating whether evaluation output
should be played back (FALSE), or whether the result value should
be printed as is (TRUE, the default)
a logical indicating whether carriage returns should be
printed, possibly overwriting characters in the output.
additional arguments unused
an numeric indicating a time to sleep between printing
each line to console. This can be helpful if the original output overwrites
valuable information in the log that is eventually overwritten and you
would like to watch it play out as it was formatted.