Learn R Programming

riskmetric (version 0.2.5)

roxygen_assess_family: Helper for creating a roxygen header from template for assess_* functions

Description

Helper for creating a roxygen header from template for assess_* functions

Usage

roxygen_assess_family(
  name,
  return_type = "an atomic assessment result",
  dontrun = TRUE
)

Value

roxygen section template for assess family functions

Arguments

name

the name of the assessment, assuming naming conventions are followed

return_type

an optional added commentary about the return type of the assessment function

dontrun

logical indicating whether examples should be wrapped in a dontrun block. This is particularly useful for assessments which may require an internet connection.

Examples

Run this code
if (FALSE) {
#' @eval roxygen_assess_family(
#'   "has_news",
#'   "an integer value indicating the number of discovered NEWS files")
}

Run the code above in your browser using DataLab