Learn R Programming

riskmetric (version 0.2.5)

roxygen_score_family: Helper for creating a roxygen header from template for score.* functions

Description

Helper for creating a roxygen header from template for score.* functions

Usage

roxygen_score_family(name, dontrun = TRUE)

Value

roxygen section template for score family functions

Arguments

name

the name of the scoring function, assuming naming conventions are followed

dontrun

logical indicating whether examples should be wrapped in a dontrun block. This is particularly useful for assessments which may require an internet connection.

Examples

Run this code
if (FALSE) {
#' @eval roxygen_score_family("has_news")
}

Run the code above in your browser using DataLab