Suppress messages and warnings based on one or more regex matches
suppressMatchingConditions(expr, ..., .opts = list(), .envir = parent.frame())a message printed on console
An expression to evaluate
Named parameters, where the name indicates the class of conditions to capture and the value is a vector of regular expressions that, when matched against the respective condition message, should suppress that condition.
A named list of arguments to pass to grepl
The environment in which expr is to be evaluated