Learn R Programming

riskmetric (version 0.2.5)

with_unclassed_to: Evaluate an expression after first removing a range of S3 classes

Description

Evaluate an expression after first removing a range of S3 classes

Usage

with_unclassed_to(x, .class = 1:length(class(x)), expr, envir = parent.frame())

Value

the result of expr

Arguments

x

a structured S3-classed object

.class

the class to unclass the object to

expr

an expression to evaluate, avoiding parent classs dispatch

envir

an environment in which the expression is to be evaluated