assess_covr_coverage: Assess a package code coverage using the `covr` package
Description
Assess a package code coverage using the `covr` package
Usage
assess_covr_coverage(x, ...)
Value
a pkg_metric containing a list containing fields 'filecoverage' and 'totalcoverage' containing a named numeric vector of file unit test coverage and a singular numeric value representing overall test coverage respectively.
Arguments
x
a pkg_ref package reference object
...
additional arguments passed on to S3 methods, rarely used