powered by
Only Depends, Imports and LinkingTo dependencies are assessed because they are required
assess_dependencies(x, ...)
a pkg_metric containing a dataframe of package names and they type of dependency the package being assess has to them
pkg_metric
a pkg_ref package reference object
pkg_ref
additional arguments passed on to S3 methods, rarely used
The more packages a package relies on the more chances for errors exist.
metric_score.pkg_metric_dependencies
if (FALSE) { assess_dependencies(pkg_ref("riskmetric")) }
Run the code above in your browser using DataLab