powered by
Assess a package for the presence of example or usage fields in function documentation
assess_has_examples(x, ...)
a pkg_metric containing an integer value indicating the proportion of discovered files with examples
pkg_metric
a pkg_ref package reference object
pkg_ref
additional arguments passed on to S3 methods, rarely used
metric_score.pkg_metric_has_examples
if (FALSE) { assess_has_examples(pkg_ref("riskmetric")) }
Run the code above in your browser using DataLab