Learn R Programming

riskmetric (version 0.2.5)

assessment_error_as_warning: Error handler for assessments to deescalate errors to warnings

Description

Error handler for assessments to deescalate errors to warnings

Usage

assessment_error_as_warning(e, name, assessment)

Value

a pkg_metric object of pkg_metric_error subclass

Arguments

e

an error raised during a package reference assessment

name

the name of the package whose package reference assessment raised the error

assessment

the name of the assessment function which raised the error

See Also

Other assessment error handlers: assessment_error_empty(), assessment_error_throw()