Error handler for assessments to deescalate errors to warnings
assessment_error_as_warning(e, name, assessment)a pkg_metric object of pkg_metric_error subclass
an error raised during a package reference assessment
the name of the package whose package reference assessment raised the error
the name of the assessment function which raised the error
Other assessment error handlers:
assessment_error_empty(),
assessment_error_throw()