make the errors and warnings consistent with meaningful indication of what triggered the error, including the name of the package whose reference triggered the error while running which asesessment.
format_assessment_message(e, name, assessment)a character string of formatted text to communicate the error
an error raised during a package reference assessment
the name of the package whose package reference assessment raised the error
the name of the assessment function which raised the error