Learn R Programming

riskmetric (version 0.2.5)

metric_score.pkg_metric_downloads_1yr: Defining an Assessment Scoring Function

Description

Score a package for the number of downloads in the past year regularized Convert the number of downloads x in the past year into a validation score [0,1] $$ 1 - 150,000 / (x + 150,000) $$

Usage

# S3 method for pkg_metric_downloads_1yr
metric_score(x, ...)

Value

numeric value between 0 (low) and 1 (high download volume) converting the number of downloads.

Arguments

x

a pkg_metric_downloads_1yr packge metric object

...

additional arguments unused

Details

The scoring function is a simplification of the classic logistic curve $$ 1 / (1 + exp(-k(x-x[0])) $$ with a log scale for the number of downloads \(x = log(x)\), sigmoid midpoint is 1000 downloads, ie. \(x[0] = log(1,000)\), and logistic growth rate of \(k = 0.5\).

$$ 1 - 1 / (1 + exp(log(x)-log(1.5e5))) = 1 - 150,000 / (x + 150,000) $$

Examples

Run this code
if (FALSE) metric_score(assess_downloads_1yr(pkg_ref("riskmetric")))

Run the code above in your browser using DataLab