The scoring function is a simplification of the classic logistic curve $$
1 / (1 + exp(-k(x-x[0])) $$ with a log scale for the number of downloads
\(x = log(x)\), sigmoid midpoint is 1000 downloads, ie. \(x[0] =
log(1,000)\), and logistic growth rate of \(k = 0.5\).
$$ 1 - 1 / (1 + exp(log(x)-log(1.5e5))) = 1 - 150,000 / (x + 150,000) $$