powered by
Coerce a logical vector indicating availability of example or usage documentation
# S3 method for pkg_metric_has_examples metric_score(x, ...)
1 if any example or usage fields are found, otherwise 0
1
0
a pkg_metric_has_examples packge metric object
pkg_metric_has_examples
additional arguments unused
if (FALSE) metric_score(assess_has_examples(pkg_ref("riskmetric")))
Run the code above in your browser using DataLab