powered by
Coerce a list of maintainers into a numeric value indicating whether the number of listed maintainers is greater than 0.
# S3 method for pkg_metric_has_maintainer metric_score(x, ...)
1 if any maintainer is provided, otherwise 0
1
0
a pkg_metric_has_maintainer packge metric object
pkg_metric_has_maintainer
additional arguments unused
if (FALSE) metric_score(assess_has_maintainer(pkg_ref("riskmetric")))
Run the code above in your browser using DataLab