powered by
Coerce a list of source control urls into a numeric value indicating whether the number of listed urls is greater than 0.
# S3 method for pkg_metric_has_source_control metric_score(x, ...)
1 if any source control url is provided, otherwise 0
1
0
a pkg_metric_has_source_control packge metric object
pkg_metric_has_source_control
additional arguments unused
if (FALSE) metric_score(assess_has_source_control(pkg_ref("riskmetric")))
Run the code above in your browser using DataLab