powered by
Coerce a list of website urls into a numeric value indicating whether the number of listed urls is greater than 0.
# S3 method for pkg_metric_has_website metric_score(x, ...)
1 if any website url is provided, otherwise 0
1
0
a pkg_metric_has_website packge metric object
pkg_metric_has_website
additional arguments unused
if (FALSE) metric_score(assess_has_website(pkg_ref("riskmetric")))
Run the code above in your browser using DataLab