Evalute code relevant to a metric, capturing the evaluated code as well as any messages, warnings or errors that are thrown in the process.
pkg_metric_eval(expr, ..., class = c(), env = parent.frame())a pkg_metric object containing the result of expr
An expression to evaluate in order to calculate a
pkg_metric
additional attributes to bind to the pkg_metric object
a subclass to differentiate the pkg_metric object
An environment in which expr is to be evaluated