roxygen section template for assess family functions
Arguments
name
the name of the assessment, assuming naming conventions are
followed
return_type
an optional added commentary about the return type of the
assessment function
dontrun
logical indicating whether examples should be wrapped in
a dontrun block. This is particularly useful for assessments which may
require an internet connection.